
local addon_name, addon = ...

function addon:AddIDLine(tip, ...)  -- idname, id
    if tip._alltheid then
        return
    end

    local line = self:IDLine(...)
    if line then
        tip:AddLine(line)
        if tip:IsShown() then
            -- force redraw
            tip:Show()
        end
        tip._alltheid = true
    end
end

do
    local tmp = {}
    function addon:IDLine(...)
        wipe(tmp)

        for i = 1,select("#", ...),2 do
            local name, id = select(i, ...)
            if id then
                tinsert(tmp, format("|cff33cc44%s ID:|r %s", name, id))
            end
        end

        if #tmp > 0 then
            return table.concat(tmp, " / ")
        end
    end
end

do
    local tmp = {}
    function addon:TextAppendID(fs, ...)
        local line = self:IDLine(...)
        local orig = fs:GetText()
        if line == fs._alltheid and strfind(orig, line) then
            return
        end

        wipe(tmp)
        tinsert(tmp, orig)
        tinsert(tmp, "\n")
        tinsert(tmp, line)
        fs:SetText(table.concat(tmp, ""))

        fs._alltheid = line
    end
end

function addon:HookTipScript(handler, func)
    if GameTooltip:HasScript(handler) then
        GameTooltip:HookScript(handler, func)
    end

    if ItemRefTooltip:HasScript(handler) then
        ItemRefTooltip:HookScript(handler, func)
    end
end

function addon:HookTip(method, hookfunc)
    if GameTooltip[method] then
        hooksecurefunc(GameTooltip, method, function(self, ...) hookfunc(GameTooltip, ...) end)
    end

    if ItemRefTooltip[method] then
        hooksecurefunc(ItemRefTooltip, method, function(self, ...) hookfunc(ItemRefTooltip, ...) end)
    end
end

addon:HookTipScript("OnTooltipCleared", function(self)
    self._alltheid = nil
end)

