
local addon_name, addon = ...

addon:HookTipScript("OnTooltipSetItem", function(self)
    local name, link = self:GetItem()
    if link then
        local _,_,id = strfind(link, "|Hitem:(%d+):")
        addon:AddIDLine(self, "Item", id)
    end
end)

addon:HookTipScript("OnTooltipSetSpell", function(self)
    local name, rank, spellID = self:GetSpell()
    addon:AddIDLine(self, "Spell", spellID)
end)

--
--
--

local tmpSetUnit = {}
function handleUnit(tip, unitType, ...) 
    if unitType == "Creature" or unitType == "Pet" or unitType == "Vehicle" then
        local _, _, _, _, id = ...
        tinsert(tmpSetUnit, "NPC")
        tinsert(tmpSetUnit, id)
    elseif unitType == "GameObject" then
        local _, _, _, _, id = ...
        tinsert(tmpSetUnit, "Object")
        tinsert(tmpSetUnit, id)
    end
end

addon:HookTipScript("OnTooltipSetUnit", function(self)
    local name, unit = self:GetUnit()
    if not unit then
        return
    end

    wipe(tmpSetUnit)

    local guid = UnitGUID(unit)
    if guid then
        handleUnit(self, strsplit("-", guid))
    end

    if UnitIsWildBattlePet(unit) then
        local speciesID = UnitBattlePetSpeciesID(unit)
        if speciesID then
            tinsert(tmpSetUnit, "Species")
            tinsert(tmpSetUnit, speciesID)
        end
    end

    if #tmpSetUnit > 0 then
        addon:AddIDLine(self, unpack(tmpSetUnit))
    end
end)

--
--
--

addon:HookTip("SetAchievementByID", function(self, id)
    addon:AddIDLine(self, "Achievement", id)
end)

addon:HookTip("SetCurrencyByID", function(self, id)
    addon:AddIDLine(self, "Currency", id)
end)

addon:HookTip("SetCurrencyToken", function(self, idx)
    -- TODO There doesn't seem to be a reasonable way to get this
end)

addon:HookTip("SetGlyph", function(self, socket, talent)
    local link = GetGlyphLink(socket, talent)
    local _,_, id = strfind(link, "|Hglyph:(%d+)|")
    addon:AddIDLine(self, "Glyph", id)
end)

addon:HookTip("SetGlyphByID", function(self, id)
    addon:AddIDLine(self, "Glyph", id)
end)

addon:HookTip("SetHyperlink", function(self, link)
    local _, _, name, id = strfind(link, "(%w+):(%d+)")
    addon:AddIDLine(self, name:gsub("^%l", string.upper), id)
end)

addon:HookTip("SetLFGCompletionReward", function(self)
    -- TODO item is handled, currency is not
end)

addon:HookTip("SetLFGDungeonReward", function(self)
    -- TODO item is handled, currency is not
end)

addon:HookTip("SetLootCurrency", function(self, slot)
    -- TODO don't know how to get currency info
end)

addon:HookTip("SetMerchantCostItem", function(self, idx, currency)
    local currencyID = select(currency, GetMerchantCurrencies())
    addon:AddIDLine(self, "Currency", currencyID)
end)

addon:HookTip("SetQuestCurrency", function(self, type, idx)
    -- TODO GetQuestCurrencyInfo(type, idx) => name, texture, count
end)

addon:HookTip("SetQuestLogCurrency", function(self, type, idx)
    -- TODO GetQuestCurrencyInfo(type, idx) => name, texture, count
end)

addon:HookTip("SetUnitAura", function(self, unit, index, filter)
    local _,_,_,_,_,_,_,_,_,_, spellID = UnitAura(unit, index, filter)
    addon:AddIDLine(self, "Spell", spellID)
end)

addon:HookTip("SetUnitBuff", function(self, unit, index, filter)
    local _,_,_,_,_,_,_,_,_,_, spellID = UnitBuff(unit, index, filter)
    addon:AddIDLine(self, "Spell", spellID)
end)

addon:HookTip("SetUnitDebuff", function(self, unit, index, filter)
    local _,_,_,_,_,_,_,_,_,_, spellID = UnitDebuff(unit, index, filter)
    addon:AddIDLine(self, "Spell", spellID)
end)
